API documentation
=================

.. raw:: html

   <script type="text/javascript">
   window.location.href = "generated/paraphernalia.html"
   </script>

You should be automatically redirected to the :py:mod:`paraphernalia` documentation.
But if not, please click below:

.. toctree::
   :includehidden:

   generated/paraphernalia
